@@ -2,7 +2,7 @@
  *
  *  Connection Manager
  *
- *  Copyright (C) 2007-2008  Intel Corporation. All rights reserved.
+ *  Copyright (C) 2007-2009  Intel Corporation. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2 as
@@ -32,6 +32,21 @@ extern "C" {
  * @short_description: Functions for registering RTNL modules
  */
 
+
+typedef void (* connman_rtnl_operstate_cb_t) (unsigned char operstate,
+							void *user_data);
+
+typedef void (* connman_rtnl_link_cb_t) (unsigned flags, unsigned change,
+							void *user_data);
+
+unsigned int connman_rtnl_add_operstate_watch(int index,
+			connman_rtnl_operstate_cb_t callback, void *user_data);
+
+unsigned int connman_rtnl_add_newlink_watch(int index,
+			connman_rtnl_link_cb_t callback, void *user_data);
+
+void connman_rtnl_remove_watch(unsigned int id);
+
 #define CONNMAN_RTNL_PRIORITY_LOW      -100
 #define CONNMAN_RTNL_PRIORITY_DEFAULT     0
 #define CONNMAN_RTNL_PRIORITY_HIGH      100
@@ -47,11 +62,8 @@ struct connman_rtnl {
 	void (*delgateway) (int index, const char *gateway);
 };
 
-extern int connman_rtnl_register(struct connman_rtnl *rtnl);
-extern void connman_rtnl_unregister(struct connman_rtnl *rtnl);
-
-int connman_rtnl_send_getlink(void);
-int connman_rtnl_send_getroute(void);
+int connman_rtnl_register(struct connman_rtnl *rtnl);
+void connman_rtnl_unregister(struct connman_rtnl *rtnl);
 
 #ifdef __cplusplus
 }
