@@ -223,6 +223,8 @@ int __connman_element_append_ipv4(struct connman_element *element,
 int __connman_element_set_ipv4(struct connman_element *element,
 				const char *name, DBusMessageIter *value);
 
+gboolean __connman_element_device_isfiltered(const char *devname);
+
 int __connman_ipv4_init(void);
 void __connman_ipv4_cleanup(void);
 
@@ -237,6 +239,7 @@ void __connman_udev_cleanup(void);
 char *__connman_udev_get_devtype(const char *ifname);
 char *__connman_udev_get_mbm_devnode(const char *ifname);
 void __connman_udev_rfkill(const char *sysname, connman_bool_t blocked);
+void __connman_udev_enable_rfkill_processing(void);
 
 #include <connman/device.h>
 
